from airpage.core import *

IDENTITY = True
XXX = lambda:...






